@@ -170,6 +170,9 @@ void Core::onControllersReady()
         }
     });
 
+    connect(PowerDevil::PolicyAgent::instance(), &PowerDevil::PolicyAgent::screenLockerActiveChanged, this, &Core::onScreenLockerActiveChanged);
+    connect(m_suspendController.get(), &SuspendController::resumeFromSuspend, this, &Core::onResumeFromSuspend);
+
     // Initialize the action pool, which may also initialize profile-independent functionality
     refreshActions();
 
@@ -198,7 +201,7 @@ void Core::onControllersReady()
     // try creating a timerfd which can wake system from suspend
     m_timerFd = timerfd_create(CLOCK_REALTIME_ALARM, TFD_CLOEXEC);
 
-    // if that fails due to privilges maybe, try normal timerfd
+    // if that fails due to privileges maybe, try normal timerfd
     if (m_timerFd == -1) {
         qCDebug(POWERDEVIL)
             << "Unable to create a CLOCK_REALTIME_ALARM timer, trying CLOCK_REALTIME\n This would mean that wakeup requests won't wake device from suspend";
@@ -582,7 +585,7 @@ bool Core::emitBatteryChargePercentNotification(int currentPercent, int previous
         return true;
     }
 
-    // Make sure a notificaton that's kept open updates its percentage live.
+    // Make sure a notification that's kept open updates its percentage live.
     updateBatteryNotifications(currentPercent);
 
     if (m_batteryController->acAdapterState() == BatteryController::Plugged && !flags.testFlag(ChargeNotificationFlag::NotifyWhenAcPluggedIn)) {
@@ -806,8 +809,8 @@ void Core::onCriticalBatteryTimerExpired()
         m_criticalBatteryNotification = nullptr;
     }
 
-    // Do that only if we're not on AC
-    if (m_batteryController->acAdapterState() == BatteryController::Unplugged) {
+    // Do that only if we're not on AC and battery level is still critical
+    if (m_batteryController->acAdapterState() == BatteryController::Unplugged && currentChargePercent() <= m_globalSettings->batteryCriticalLevel()) {
         triggerCriticalBatteryAction();
     }
 }
@@ -981,6 +984,22 @@ void Core::onServiceRegistered(const QString &service)
     }
 }
 
+void Core::onScreenLockerActiveChanged(bool active)
+{
+    if (active) {
+        return;
+    }
+    const int percent = currentChargePercent();
+    emitBatteryChargePercentNotification(percent, 1000);
+}
+
+void Core::onResumeFromSuspend() {
+    const int percent = currentChargePercent();
+    emitBatteryChargePercentNotification(percent, 1000);
+
+    m_batteryController->updateAcAdapterState();
+}
+
 void Core::readChargeThreshold()
 {
     KAuth::Action action(QStringLiteral("org.kde.powerdevil.chargethresholdhelper.getthreshold"));
@@ -1225,7 +1244,7 @@ void Core::timerfdEventHandler()
 
     // At this point scheduled wakeup list should not be empty, but just in case
     if (m_scheduledWakeups.isEmpty()) {
-        qWarning(POWERDEVIL) << "Wakeup was recieved but list is now empty! This should not happen!";
+        qWarning(POWERDEVIL) << "Wakeup was received but list is now empty! This should not happen!";
         return;
     }
 
